"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * A reimplementation of React Native Screens for React NativeScript.
 * @see https://github.com/software-mansion/react-native-screens/blob/73959abc975b5718e683d39f1452ec0bb4d5f475/native-stack/navigators/createNativeStackNavigator.tsx
 */
var React = require("react");
var core_1 = require("@react-navigation/core");
var screens_1 = require("../../react-nativescript-screens/screens");
var NativeStackView_1 = require("../views/NativeStackView");
function NativeStackNavigator(props) {
    if (!screens_1.screensEnabled()) {
        throw new Error('Native stack is only available if React Native Screens is enabled.');
    }
    var initialRouteName = props.initialRouteName, children = props.children, screenOptions = props.screenOptions, rest = __rest(props, ["initialRouteName", "children", "screenOptions"]);
    var _a = core_1.useNavigationBuilder(core_1.StackRouter, {
        initialRouteName: initialRouteName,
        children: children,
        screenOptions: screenOptions,
    }), state = _a.state, descriptors = _a.descriptors, navigation = _a.navigation;
    React.useEffect(function () {
        return navigation.addListener &&
            navigation.addListener('tabPress', function (e) {
                var isFocused = navigation.isFocused();
                // Run the operation in the next frame so we're sure all listeners have been run
                // This is necessary to know if preventDefault() has been called
                requestAnimationFrame(function () {
                    if (state.index > 0 &&
                        isFocused &&
                        !e.defaultPrevented) {
                        // When user taps on already focused tab and we're inside the tab,
                        // reset the stack to replicate native behaviour
                        navigation.dispatch(__assign(__assign({}, core_1.StackActions.popToTop()), { target: state.key }));
                    }
                });
            });
    }, [navigation, state.index, state.key]);
    return (React.createElement(NativeStackView_1.default, __assign({}, rest, { state: state, navigation: navigation, descriptors: descriptors })));
}
exports.default = core_1.createNavigatorFactory(NativeStackNavigator);
//# sourceMappingURL=createNativeStackNavigator.js.map