"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * A reimplementation of React Native Screens for React NativeScript.
 * @see https://github.com/software-mansion/react-native-screens/blob/73959abc975b5718e683d39f1452ec0bb4d5f475/native-stack/views/NativeStackView.tsx
 */
var React = require("react");
// import { View, StyleSheet, Platform } from 'react-native';
var screens_1 = require("../../react-nativescript-screens/screens");
var core_1 = require("@react-navigation/core");
var HeaderConfig_1 = require("./HeaderConfig");
var core_2 = require("@nativescript/core");
var Screen = screens_1.Screen;
/**
 *
 * @see https://github.com/software-mansion/react-native-screens/blob/73959abc975b5718e683d39f1452ec0bb4d5f475/native-stack/views/NativeStackView.tsx#L27
 */
function NativeStackView(_a) {
    var state = _a.state, navigation = _a.navigation, descriptors = _a.descriptors;
    // const { colors } = useTheme();
    console.log("[NativeStackView] " + JSON.stringify(state.routes.map(function (route) { return route.key; })));
    return (
    // Frame
    React.createElement(screens_1.ScreenStack, { style: styles.container }, state.routes.map(function (route, index, self) {
        var _a = descriptors[route.key], options = _a.options, renderScene = _a.render;
        var _b = options.gestureEnabled, gestureEnabled = _b === void 0 ? true : _b, _c = options.stackPresentation, stackPresentation = _c === void 0 ? 'push' : _c, stackAnimation = options.stackAnimation, contentStyle = options.contentStyle, headerShown = options.headerShown;
        var active = index === self.length - 1;
        return (
        // Page
        React.createElement(Screen, { key: route.key, active: active ? 1 : 0, style: styles.fill, backgroundColor: "red", actionBarHidden: !headerShown, gestureEnabled: core_2.isAndroid ? false : gestureEnabled, stackPresentation: stackPresentation, stackAnimation: stackAnimation, onWillDisappear: function (args) {
                console.log("[Screen." + route.key + " " + args.object + "] 'willDisappear'.");
            }, onDidDisappear: function (args) {
                var page = args.object;
                var frame = page.frame;
                if (frame && frame._currentEntry && frame._currentEntry.resolvedPage === page) {
                    console.log("[Screen." + route.key + " " + args.object + "] 'didDisappear'. Still currentPage.");
                    // "First" screen fires this upon disappearing when navigating forward to "Second" via React Navigation.
                    // "Second" screen fires this upon disappearing when navigating backward to "First" via React Navigation.
                    // "Second" screen fires this upon disappearing when navigating backward to "First" via user.
                }
                else {
                    console.log("[Screen." + route.key + " " + args.object + "] 'didDisappear'. No longer currentPage.");
                }
                navigation.emit({
                    type: 'didDisappear',
                    target: route.key,
                });
                /**
                 * When navigation.navigate('second') is called, a route is pushed to state.routes.
                 * This causes RNS to call parent.insert(child), which involves frame.navigate({ create(): { return page; } });
                 *
                 * When navigation.goBack() is called, a route is popped from state.routes.
                 * This causes RNS to call parent.remove(child), which involves frame.goBack();
                 *
                 * So, in those two cases, there's no need to dispatch a "POP" action to bring state.routes back in sync
                 * with the stack maintained by the Frame. Because the ReactChildren are driving the navigation state.
                 *
                 * The worrying cases come from Frame's side:
                 * – Android back button (pop)
                 * – Right swipe (pop)
                 * – Press "back" navigation button (pop)
                 *
                 * If this were purely RNS (no React Navigation), we'd need to capture (and more importantly, discern) these
                 * events and manually pop the necessary Page(s) off our Frame's array of ReactChildren.
                 *
                 * The same goes for React Navigation, with the subtlety that said array (state.routes) is managed internally
                 * by React Navigation. To pop from it, we must dispatch a "POP" action.
                 *
                 * However, we will also need to rely on some implicit behaviour in the RNS registry. If ever
                 * parent.remove(child) is called for a child that is not the currentPage of the frame, we must be careful
                 * _not_ to call frame.goBack() (because it has already been done); instead, we must simply no-op.
                 *
                 *
                 *
                 */
            }, onWillAppear: function (args) {
                console.log("[Screen." + route.key + " " + args.object + "] 'willAppear'.");
            }, onDidAppear: function (args) {
                // Software Mansion's NativeStackView chooses to emit before the dispatch.
                navigation.emit({
                    type: 'didAppear',
                    target: route.key,
                });
                var page = args.object;
                var frame = page.frame;
                if (frame && frame._currentEntry && frame._currentEntry.resolvedPage === page) {
                    // "Second" screen fires this upon appearing when being navigating forward to from "First" via React Navigation.
                    // "First" screen fires this upon appearing when being navigating backward to from "Second" via React Navigation.
                    // "First" screen fires this upon appearing when being navigating backward to from "Second" via user.
                    console.log("[Screen." + route.key + " " + args.object + "] 'didAppear', becoming currentPage. active: " + active);
                    if (!active) {
                        var topRoute = state.routes[state.routes.length - 1];
                        navigation.dispatch(__assign(__assign({}, core_1.StackActions.pop()), { source: topRoute.key, target: state.key }));
                    }
                }
                else {
                    console.log("[Screen." + route.key + " " + args.object + "] 'didAppear', but not becoming currentPage.");
                }
            } },
            React.createElement(HeaderConfig_1.default, __assign({}, options, { route: route })),
            React.createElement("flexboxLayout", { nodeRole: "content", style: __assign(__assign({}, styles.flexContainer), contentStyle) }, renderScene())));
    })));
}
exports.default = NativeStackView;
var styles = {
    fill: {
        width: "100%",
        height: "100%",
    },
    container: {
        width: "100%",
        height: "100%",
    },
    flexContainer: {
        flexGrow: 1,
        flexDirection: "column",
        width: "100%",
        height: "100%",
    },
};
//# sourceMappingURL=NativeStackView.js.map