"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScreenStack = exports.NativeScreenContainer = exports.ScreenContainer = exports.Screen = exports.ScreenStackHeaderCenterView = exports.ScreenStackHeaderLeftView = exports.ScreenStackHeaderRightView = exports.ScreenStackHeaderBackButtonImage = exports.ScreenStackHeaderConfig = exports.NativeScreen = exports.screensEnabled = exports.enableScreens = void 0;
/**
 * A reimplementation of React Native Screens for React NativeScript.
 * @see https://github.com/software-mansion/react-native-screens/blob/73959abc975b5718e683d39f1452ec0bb4d5f475/src/screens.native.js
 */
var React = require("react");
var ENABLE_SCREENS = true;
function enableScreens(shouldEnableScreens) {
    if (shouldEnableScreens === void 0) { shouldEnableScreens = true; }
    ENABLE_SCREENS = shouldEnableScreens;
}
exports.enableScreens = enableScreens;
function screensEnabled() {
    return ENABLE_SCREENS;
}
exports.screensEnabled = screensEnabled;
/**
 * @see https://github.com/software-mansion/react-native-screens/blob/master/src/screens.web.js
 * @see https://docs.nativescript.org/ui/components/page#page-events
 */
var NativeScreen = /** @class */ (function (_super) {
    __extends(NativeScreen, _super);
    function NativeScreen(props) {
        var _this = _super.call(this, props) || this;
        // 1
        _this.onNavigatingFrom = function (args) {
            _this.props.onWillDisappear && _this.props.onWillDisappear(args); // √
        };
        // 2
        _this.onNavigatingTo = function (args) {
            _this.setState({ onscreen: true });
            _this.props.onWillAppear && _this.props.onWillAppear(args);
        };
        // 3
        _this.onNavigatedFrom = function (args) {
            _this.props.onDidDisappear && _this.props.onDidDisappear(args);
            // this.setState({ onscreen: false }); // Can't perform state update on unmounted component.
        };
        // 4
        _this.onNavigatedTo = function (args) {
            _this.props.onDidAppear && _this.props.onDidAppear(args);
        };
        _this.state = {
            onscreen: props.active === 1,
        };
        return _this;
    }
    NativeScreen.prototype.render = function () {
        var _a = this.props, active = _a.active, gestureEnabled = _a.gestureEnabled, style = _a.style, rest = __rest(_a, ["active", "gestureEnabled", "style"]);
        // console.log(`[NativeScreen] ENABLE_SCREENS && !active ${ENABLE_SCREENS && !active}`);
        return (React.createElement("page", __assign({ enableSwipeBackNavigation: gestureEnabled, onNavigatingTo: this.onNavigatingTo, onNavigatedTo: this.onNavigatedTo, onNavigatedFrom: this.onNavigatedFrom, onNavigatingFrom: this.onNavigatingFrom, style: __assign(__assign({}, style), (ENABLE_SCREENS && !active && !this.state.onscreen ?
                {
                    visibility: 'collapse' // Because `display: 'none'` doesn't exist in NativeScript
                } :
                {})) }, rest)));
    };
    return NativeScreen;
}(React.Component));
exports.NativeScreen = NativeScreen;
var styles = {
    headerSubview: {
    // position: 'absolute',
    // top: 0,
    // right: 0,
    // flexDirection: 'row',
    // alignItems: 'center',
    // justifyContent: 'center',
    },
    content: {
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
    },
    left: {
    // position: 'absolute',
    // left: 0,
    // top: 0,
    // bottom: 0,
    // justifyContent: 'center',
    // alignItems: 'flex-start',
    },
    right: {
    // position: 'absolute',
    // right: 0,
    // top: 0,
    // bottom: 0,
    // justifyContent: 'center',
    // alignItems: 'flex-end',
    },
    headerCenterView: {
        width: "100%",
        height: "100%",
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
    },
};
exports.ScreenStackHeaderConfig = function (props) {
    var _a = props.style, style = _a === void 0 ? {} : _a;
    return (React.createElement("actionBar", __assign({ nodeRole: "actionBar", style: style }, props)));
};
exports.ScreenStackHeaderBackButtonImage = function (props) {
    var _a = props.style, style = _a === void 0 ? {} : _a;
    return (React.createElement("navigationButton", __assign({ nodeRole: "navigationButton", style: style }, props)));
};
exports.ScreenStackHeaderRightView = function (props) {
    var tintColor = props.tintColor, _a = props.style, style = _a === void 0 ? {} : _a, children = props.children;
    return (React.createElement("actionItem", { nodeRole: "actionItems", ios: { position: "right", systemIcon: undefined }, android: { position: "popup", systemIcon: undefined }, style: __assign(__assign({}, style), { backgroundColor: tintColor }) }, children));
};
exports.ScreenStackHeaderLeftView = function (props) {
    var tintColor = props.tintColor, _a = props.style, style = _a === void 0 ? {} : _a, children = props.children;
    return (React.createElement("actionItem", { nodeRole: "actionItems", ios: { position: "left", systemIcon: undefined }, 
        // Note: Android does not support actionItems on left, to my understanding.
        android: { position: "popup", systemIcon: undefined }, style: __assign(__assign({}, style), { backgroundColor: tintColor }) }, children));
};
exports.ScreenStackHeaderCenterView = function (props) {
    var tintColor = props.tintColor, _a = props.style, style = _a === void 0 ? {} : _a, children = props.children;
    return (React.createElement("flexboxLayout", __assign({ nodeRole: "titleView" }, props, { style: __assign(__assign(__assign({}, styles.headerCenterView), style), { backgroundColor: tintColor }) }), children));
};
exports.Screen = NativeScreen;
exports.ScreenContainer = "flexboxLayout";
exports.NativeScreenContainer = "flexboxLayout";
// ScreenStack contains any number of Screen components.
exports.ScreenStack = "frame";
//# sourceMappingURL=screens.js.map